==> accumulo-2.1.0-src.tar.gz: accumulo-2.1.0/core/src/main/java/org/apache/accumulo/core/client/AccumuloException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.core.client;

/**
 * A generic Accumulo Exception for general accumulo failures.
 */
public class AccumuloException extends Exception {

  private static final long serialVersionUID = 1L;

  /**
   * @param why
   *          is the reason for the error being thrown
   */
  public AccumuloException(final String why) {
    super(why);
  }

  /**
   * @param cause
   *          is the exception that this exception wraps
   */
  public AccumuloException(final Throwable cause) {
    super(cause);
  }

  /**
   * @param why
   *          is the reason for the error being thrown
   * @param cause
   *          is the exception that this exception wraps
   */
  public AccumuloException(final String why, final Throwable cause) {
    super(why, cause);
  }

}

==> accumulo-2.1.4-src.tar.gz: accumulo-2.1.4/core/src/main/java/org/apache/accumulo/core/client/AccumuloException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.core.client;

/**
 * A generic Accumulo Exception for general accumulo failures.
 */
public class AccumuloException extends Exception {

  private static final long serialVersionUID = 1L;

  /**
   * @param why is the reason for the error being thrown
   */
  public AccumuloException(final String why) {
    super(why);
  }

  /**
   * @param cause is the exception that this exception wraps
   */
  public AccumuloException(final Throwable cause) {
    super(cause);
  }

  /**
   * @param why is the reason for the error being thrown
   * @param cause is the exception that this exception wraps
   */
  public AccumuloException(final String why, final Throwable cause) {
    super(why, cause);
  }

}
